%% Many cycles
load 'LongData.mat';

iLeft = find([out.duration] < 1.1);
iRight = find(([out.duration] > 1.1 )& ([out.duration] < 4.99));
iFail = find([out.duration] > 4.99);
durs = [out.duration];
r = [out.vMon];

N = [1:length(out)]/2;

%%
figure(1);
set(gca, 'FontSize', 16);
plot(N(iLeft)/1000, durs(iLeft),  '*', ...
    N(iRight)/1000, durs(iRight), '*', ...
    N(iFail)/1000, durs(iFail),   '*');
axis([0 10.5 0 5.1]);
ylabel('Duration [s]');
xlabel('Cycle Number [x1000]');

myPrint(1, '10kCycles.pdf');

figure(11)
set(gca, 'FontSize', 16);
plot(N(iLeft)/1000, r(iLeft),  '*', ...
    N(iRight)/1000, r(iRight), '*', ...
    N(iFail)/1000, r(iFail),   '*');
axis([0 10.5 .4 .5]);
ylabel('Current');
xlabel('Cycle Number [x1000]');

%% Temperature

load 'Resistance_1v';
d1 = data;
load 'Resistance_1p5v';
d2 = data;
load 'Resistance_2v';
d3 = data;

r1 = -d1.vMon./d1.iMon;
r2 = -d2.vMon./d2.iMon;
r3 = -d3.vMon./d3.iMon;
t = d1.t;

figure(2)
set(gca, 'FontSize', 16);
plot(t, [r1 r2 r3]);
axis([0 100 5.5 7])
xlabel('Time [s]');
ylabel('Resistance [Ohm]');
legend('P_0 = 0.7 W', 'P_0 = 1.5 W', 'P_0 = 2.7 W', 'Location', 'NorthWest');
shg
myPrint(2, 'Resistance.pdf');

figure(3)
set(gca, 'FontSize', 16);
plot(t, [d1.iMon.^2.*r1 d2.iMon.^2.*r2 d3.iMon.^2.*r3]);
axis([0 100 0 4])
ylabel('Power dissipated [W]');
xlabel('Time [s]');
legend('P_0 = 0.7 W', 'P_0 = 1.5 W', 'P_0 = 2.7 W', 'Location', 'NorthEast');

figure(4)
r0 = 6;
drdt = 3e-3;
T1 = (r1-r0)/r0/drdt;
T2 = (r2-r0)/r0/drdt;
T3 = (r3-r0)/r0/drdt;
set(gca, 'FontSize', 16);
plot(t, [T1 T2 T3]);
axis([0 100 -10 40])
ylabel('Temperature [K]');
xlabel('Time [s]');
legend('P_0 = 0.7 W', 'P_0 = 1.5 W', 'P_0 = 2.7 W', 'Location', 'NorthWest');
myPrint(4, 'Temperature.pdf');

